@@ -2,11 +2,12 @@ package Mojolicious::Plugin::AssetPack::Pipe::Sass;
 use Mojo::Base 'Mojolicious::Plugin::AssetPack::Pipe';
 
 use Mojolicious::Plugin::AssetPack::Util qw(checksum diag dumper load_module DEBUG);
+use Mojo::File;
 use Mojo::JSON qw(decode_json encode_json);
 use Mojo::Util;
 
-my $FORMAT_RE              = qr{^s[ac]ss$};
-my $IMPORT_RE              = qr{( \@import \s+ (["']) (.*?) \2 \s* ; )}x;
+my $FORMAT_RE = qr{^s[ac]ss$};
+my $IMPORT_RE = qr{ (^|[\n\r]+) ([^\@]*) (\@import \s+ (["']) (.*?) \4 \s* ;)}sx;
 my $SOURCE_MAP_PLACEHOLDER = sprintf '__%s__', __PACKAGE__;
 
 $SOURCE_MAP_PLACEHOLDER =~ s!::!_!g;
@@ -99,14 +100,17 @@ sub _checksum {
 
 SEARCH:
   while ($$ref =~ /$IMPORT_RE/gs) {
-    my $rel_path = $3;
+    my $pre      = $2;
+    my $rel_path = $5;
+    my $mlen     = length $3;
     my @rel      = split '/', $rel_path;
     my $name     = pop @rel;
-    my $mlen     = length $1;
     my $start    = pos($$ref) - $mlen;
     my $dynamic  = $rel_path =~ m!http://local/!;
     my @basename = ("_$name", $name);
 
+    next if $pre =~ m{^\s*//};
+
     # Follow sass rules for skipping,
     # ...with exception for special assetpack handling for dynamic sass include
     next if $rel_path =~ /\.css$/;
@@ -145,7 +149,7 @@ sub _install_sass {
   my $self = shift;
   $self->run([qw(ruby -rubygems -e), 'puts Gem.user_dir'], undef, \my $base);
   chomp $base;
-  my $path = path($base, qw(bin sass));
+  my $path = Mojo::File->new($base, qw(bin sass));
   return $path if -e $path;
   $self->app->log->warn(
     'Installing sass... Please wait. (gem install --user-install sass)');
